v0.4.49 allow IP parameters for networks, and network types in RO

Change-Id: I01ac9b0d006b7069555566bac7ba23d84de55312
Signed-off-by: garciadeblas <gerardo.garciadeblas@telefonica.com>
diff --git a/vimconn.py b/vimconn.py
index 36c3b52..7e82590 100644
--- a/vimconn.py
+++ b/vimconn.py
@@ -160,9 +160,11 @@
         '''
         raise vimconnNotImplemented( "Should have implemented this" )
 
-    def new_network(self,net_name, net_type, shared=False):
+    def new_network(self,net_name, net_type, ip_profile=None, shared=False):
         '''Adds a tenant network to VIM
-            net_type can be 'bridge','data'.'ptp'.  TODO: this need to be revised 
+            net_name is the name
+            net_type can be 'bridge','data'.'ptp'.  TODO: this need to be revised
+            ip_profile is a dict containing the IP parameters of the network 
             shared is a boolean
         Returns the network identifier'''
         raise vimconnNotImplemented( "Should have implemented this" )